about summary refs log tree commit diff
path: root/src/test/compile-fail/kindck-send-object.rs
diff options
context:
space:
mode:
authorNick Cameron <ncameron@mozilla.com>2015-01-06 14:03:46 +1300
committerNick Cameron <ncameron@mozilla.com>2015-01-07 09:45:28 +1300
commit503709708c72401dbe091ed5c7e0494efabe0669 (patch)
treef49a23475150a74cce2c203aa56a735d51564a1c /src/test/compile-fail/kindck-send-object.rs
parent6539cb417f4a7c2d9d1afce44c196578d2b67f38 (diff)
downloadrust-503709708c72401dbe091ed5c7e0494efabe0669.tar.gz
rust-503709708c72401dbe091ed5c7e0494efabe0669.zip
Change `std::kinds` to `std::markers`; flatten `std::kinds::marker`
[breaking-change]
Diffstat (limited to 'src/test/compile-fail/kindck-send-object.rs')
-rw-r--r--src/test/compile-fail/kindck-send-object.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/test/compile-fail/kindck-send-object.rs b/src/test/compile-fail/kindck-send-object.rs
index c300096caf1..1235a0a1228 100644
--- a/src/test/compile-fail/kindck-send-object.rs
+++ b/src/test/compile-fail/kindck-send-object.rs
@@ -20,11 +20,11 @@ trait Message : Send { }
 
 fn object_ref_with_static_bound_not_ok() {
     assert_send::<&'static (Dummy+'static)>();
     //~^ ERROR the trait `core::kinds::Send` is not implemented
 }
 
 fn box_object_with_no_bound_not_ok<'a>() {
-    assert_send::<Box<Dummy>>(); //~ ERROR the trait `core::kinds::Send` is not implemented
+    assert_send::<Box<Dummy>>(); //~ ERROR the trait `core::markers::Send` is not implemented
 }
 
 fn object_with_send_bound_ok() {
@@ -20,11 +20,11 @@ trait Message : Send { }
 fn object_ref_with_static_bound_not_ok() {
     assert_send::<&'static (Dummy+'static)>();
-    //~^ ERROR the trait `core::kinds::Send` is not implemented
+    //~^ ERROR the trait `core::markers::Send` is not implemented
 }
 